### CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International          

### https://github.com/cyborg-ai-git                                                      

# evo_package_assistant-python

evo_package_assistant DOC

## [CyborgAI](https://cyborgai.fly.dev) 

<img src="https://avatars.githubusercontent.com/u/129898917?v=4" alt="cyborgai" width="256" height="256">

## Installation

1. **PyPi install:**

    ```bash
    pip install evo_package_assistant -U -no-cache-dir
    ```

2. **Install dependencies using Poetry:**

    ```bash
    poetry install
    ```

3. **Activate the virtual environment (if not automatically activated):**

    ```bash
    poetry shell
    ```

## Usage

Instructions for using your project.

- run_publish.sh 

 export TOKEN_PYPY=


 [YouTube](https://www.youtube.com/watch?v=OnZAlOs09p4)